import setuptools

with open("README.md", "r") as fh:
    long_description = fh.read()

setuptools.setup(
    name="pyautomouse",
    version="0.0.2",
    author="xiongtianshuo",
    author_email="seoul1k@163.com",
    url='https://github.com/seoul2k/pyautomouse',
    long_description=long_description,
    long_description_content_type="text/markdown",
    license='MIT',
    project_urls={
        "Bug Tracker": "https://github.com/seoul2k/pyautomouse/issues",
    },
    classifiers=[
        "Programming Language :: Python :: 3",
        "License :: OSI Approved :: MIT License",
        "Operating System :: OS Independent",
    ],
    package_dir={"": "src"},
    install_requires=['pyautogui', 'time'],
    packages=setuptools.find_packages(where="src"),
    python_requires=">=3.6",
)
